aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.BL
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2018-03-05 20:33:02 +0200
committerRoy Ben-Shabat <Roy@Twine-s.com>2018-03-05 20:33:02 +0200
commit7e6c673cc8b04086fa3c78cd1bf5e31085fd8cc8 (patch)
treec88947de8bdbea8c69e636ebcd8b8752cb61e870 /Software/Visual_Studio/Tango.BL
parent628819a1787290f84c22ecc7cb747f649fd54468 (diff)
downloadTango-7e6c673cc8b04086fa3c78cd1bf5e31085fd8cc8.tar.gz
Tango-7e6c673cc8b04086fa3c78cd1bf5e31085fd8cc8.zip
Working on color lab module !
Diffstat (limited to 'Software/Visual_Studio/Tango.BL')
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/Cat.cs56
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/Machine.cs21
-rw-r--r--Software/Visual_Studio/Tango.BL/ObservablesContext.cs1
3 files changed, 71 insertions, 7 deletions
diff --git a/Software/Visual_Studio/Tango.BL/Entities/Machine.cs b/Software/Visual_Studio/Tango.BL/Entities/Machine.cs
index a704f47f0..f92d7bcdd 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/Machine.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/Machine.cs
@@ -137,6 +137,25 @@ namespace Tango.BL.Entities
}
+ protected ObservableCollection<Cat> _cats;
+ /// <summary>
+ /// Gets or sets the machine cats.
+ /// </summary>
+
+ public virtual ObservableCollection<Cat> Cats
+ {
+ get
+ {
+ return _cats;
+ }
+
+ set
+ {
+ _cats = value; RaisePropertyChanged(nameof(Cats));
+ }
+
+ }
+
protected Configuration _configuration;
/// <summary>
/// Gets or sets the machine configuration.
@@ -263,6 +282,8 @@ namespace Tango.BL.Entities
public Machine() : base()
{
+ Cats = new ObservableCollection<Cat>();
+
Jobs = new ObservableCollection<Job>();
MachinesConfigurations = new ObservableCollection<MachinesConfiguration>();
diff --git a/Software/Visual_Studio/Tango.BL/ObservablesContext.cs b/Software/Visual_Studio/Tango.BL/ObservablesContext.cs
index f265657ec..aa64cebcb 100644
--- a/Software/Visual_Studio/Tango.BL/ObservablesContext.cs
+++ b/Software/Visual_Studio/Tango.BL/ObservablesContext.cs
@@ -11,6 +11,7 @@ namespace Tango.BL
{
public partial class ObservablesContext : DbContext
{
+
/// <summary>
/// Gets or sets the ActionTypes.
/// </summary>
diff --git a/Software/Visual_Studio/Tango.BL/Entities/Cat.cs b/Software/Visual_Studio/Tango.BL/Entities/Cat.cs
index 69b1cab18..8af866549 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/Cat.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/Cat.cs
@@ -34,23 +34,23 @@ namespace Tango.BL.Entities
}
- protected String _liquidtypeguid;
+ protected String _machineguid;
/// <summary>
/// Gets or sets the cat liquid type guid.
/// </summary>
- [Column("LIQUID_TYPE_GUID")]
- [ForeignKey("LiquidType")]
+ [Column("MACHINE_GUID")]
+ [ForeignKey("Machine")]
- public String LiquidTypeGuid
+ public String MachineGuid
{
get
{
- return _liquidtypeguid;
+ return _machineguid;
}
set
{
- _liquidtypeguid = value; RaisePropertyChanged(nameof(LiquidTypeGuid));
+ _machineguid = value; RaisePropertyChanged(nameof(MachineGuid));
}
}
@@ -76,6 +76,27 @@ namespace Tango.BL.Entities
}
+ protected String _liquidtypeguid;
+ /// <summary>
+ /// Gets or sets the cat liquid type guid.
+ /// </summary>
+ [Column("LIQUID_TYPE_GUID")]
+ [ForeignKey("LiquidType")]
+
+ public String LiquidTypeGuid
+ {
+ get
+ {
+ return _liquidtypeguid;
+ }
+
+ set
+ {
+ _liquidtypeguid = value; RaisePropertyChanged(nameof(LiquidTypeGuid));
+ }
+
+ }
+
protected Byte[] _data;
/// <summary>
/// Gets or sets the cat data.
@@ -117,6 +138,27 @@ namespace Tango.BL.Entities
}
+ protected Machine _machine;
+ /// <summary>
+ /// Gets or sets the cat machine.
+ /// </summary>
+
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual Machine Machine
+ {
+ get
+ {
+ return _machine;
+ }
+
+ set
+ {
+ _machine = value; RaisePropertyChanged(nameof(Machine));
+ }
+
+ }
+
protected Rml _rml;
/// <summary>
/// Gets or sets the cat rml.
@@ -34,23 +34,23 @@ namespace Tango.BL.Entities
/// <summary>
- /// Gets or sets the cat liquid type guid.
+ /// Gets or sets the cat machine guid.
/// </summary>